
import scSpatial.dataset
import scSpatial.segmentation
import scSpatial.viewer
import scSpatial.widgets
import scSpatial.analysis
import scSpatial.app

VERSION = "0.1.2"


def run():
    "Entry point for CLI"
    app = scSpatial.app.App()